@@ -3,7 +3,7 @@ wBACON_reg <- function(formula, weights = NULL, data, collect = 4,
     verbose = FALSE, original = FALSE, n_threads = 2)
 {
 	stopifnot(alpha < 1, alpha > 0, collect > 0, maxiter > 0, collect > 0,
-        n_threads > 0)
+              n_threads > 0)
 	if (!inherits(formula, "formula"))
 		stop("Argument '", formula, "' must be a formula\n", call. = FALSE)
 
@@ -44,7 +44,7 @@ wBACON_reg <- function(formula, weights = NULL, data, collect = 4,
 	if (verbose)
 		cat("\nOutlier detection (Algorithm 3)\n---\n")
 	wb <- wBACON(if (attr(mt, "intercept")) x[, -1] else x, weights, alpha,
-        collect, version, na.rm, maxiter, verbose)
+                 collect, version, na.rm, maxiter, verbose)
 
 	if (isFALSE(wb$converged))
 		stop("wBACON on the design matrix failed\n")
@@ -53,42 +53,34 @@ wBACON_reg <- function(formula, weights = NULL, data, collect = 4,
 	if (verbose)
 		cat("\nRegression\n---\n")
 	collect <- min(collect, floor(n / p))
-	tmp <- .C("wbacon_reg", x = as.double(x), y = as.double(y),
-		w = as.double(weights), resid = as.double(numeric(n)),
-		beta = as.double(numeric(p)), subset = as.integer(wb$subset),
-		dist = as.double(wb$dist), n = as.integer(n), p = as.integer(p),
-		m = as.integer(sum(wb$subset)), verbose = as.integer(verbose),
-		sucess = as.integer(1), collect = as.integer(collect),
-		alpha = as.double(alpha), maxiter = as.integer(maxiter),
-        original = as.integer(original), n_threads = as.integer(n_threads),
-        PACKAGE = "wbacon")
+	tmp <- .C(C_wbacon_reg, x = as.double(x), y = as.double(y),
+              w = as.double(weights), resid = as.double(numeric(n)),
+              beta = as.double(numeric(p)), subset = as.integer(wb$subset),
+              dist = as.double(wb$dist), n = as.integer(n), p = as.integer(p),
+              m = as.integer(sum(wb$subset)), verbose = as.integer(verbose),
+              sucess = as.integer(1), collect = as.integer(collect),
+              alpha = as.double(alpha), maxiter = as.integer(maxiter),
+              original = as.integer(original),
+              n_threads = as.integer(n_threads))
 
 	# cast the QR factorization as returned by LAPACK:dgeqrf to a 'qr' object
 	QR <- structure(
-		list(qr = matrix(tmp$x, ncol = p),
-		qraux = rep(NA, p),
-		pivot = 1L:p,
-		tol = NA,
-		rank = p), class = "qr")
+		list(qr = matrix(tmp$x, ncol = p), qraux = rep(NA, p), pivot = 1L:p,
+             tol = NA, rank = p), class = "qr")
 
 	# return value
-	res <- list(coefficients = tmp$beta,
-		residuals = tmp$resid,
-		rank = p,
-		fitted.values = y - tmp$resid,
-		df.residual = sum(weights[tmp$subset == 1]) - p,
-		call = match.call(),
-		terms = mt,
-		model = mf,
-		weights = weights,
-		qr = QR,
-		subset = (tmp$subset == 1),
-		reg = list(converged = as.logical(tmp$sucess), collect = collect,
-			version = version, alpha = alpha, maxiter = tmp$maxiter,
-			dist = tmp$dist, cutoff = qt(alpha / (2 * (tmp$m + 1)), tmp$m - p,
-            lower.tail = FALSE)),
-		mv = list(center = wb$center, cov = wb$cov, dist = wb$dist,
-            cutoff = wb$cutoff))
+	res <- list(coefficients = tmp$beta, residuals = tmp$resid, rank = p,
+                fitted.values = y - tmp$resid,
+                df.residual = sum(weights[tmp$subset == 1]) - p,
+                call = match.call(), terms = mt, model = mf, weights = weights,
+                qr = QR, subset = (tmp$subset == 1),
+                reg = list(converged = as.logical(tmp$sucess),
+                           collect = collect, version = version, alpha = alpha,
+                           maxiter = tmp$maxiter, dist = tmp$dist,
+                           cutoff = qt(alpha / (2 * (tmp$m + 1)),
+                                       tmp$m - p, lower.tail = FALSE)),
+                mv = list(center = wb$center, cov = wb$cov, dist = wb$dist,
+                          cutoff = wb$cutoff))
 	names(res$coefficients) <- colnames(x)
 	class(res) <- "wbaconlm"
 	res
@@ -99,16 +91,16 @@ print.wbaconlm <- function(x, digits = max(3L, getOption("digits") - 3L), ...)
 	if (x$reg$converged){
 		n <- length(x$residuals)
 		cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
-			"\n", sep = "")
+            "\n", sep = "")
 		n_subset <- sum(x$subset)
 		cat(paste0("\nRegression on the subset of ", n_subset, " out of ", n,
-			" observations (", round(100 * n_subset / n, 1), "%)\n"))
+                   " observations (", round(100 * n_subset / n, 1), "%)\n"))
 		cat("\nCoefficients:\n")
 		print.default(format(x$coefficients, digits = digits), print.gap = 2L,
-			quote = FALSE)
+                      quote = FALSE)
 	} else {
 		cat(paste0("Algorithm did not converge in ", x$reg$maxiter,
-			" iterations!\n\n"))
+                   " iterations!\n\n"))
 	}
 	invisible(x)
 }
@@ -141,8 +133,9 @@ summary.wbaconlm <- function (object, ...)
     ans <- object[c("call", "terms", if (!is.null(object$weights)) "weights")]
     ans$residuals <- r
     ans$coefficients <- cbind(Estimate = est, `Std. Error` = se,
-        `t value` = tval, `Pr(>|t|)` = 2 * stats::pt(abs(tval), rdf,
-        lower.tail = FALSE))
+                              `t value` = tval,
+                              `Pr(>|t|)` = 2 * stats::pt(abs(tval), rdf,
+                                                         lower.tail = FALSE))
     ans$aliased <- is.na(object$coefficients)
     ans$sigma <- sqrt(resvar)
     ans$df <- c(p, rdf, NCOL(qr$qr))
@@ -151,7 +144,7 @@ summary.wbaconlm <- function (object, ...)
         ans$r.squared <- mss / (mss + rss)
         ans$adj.r.squared <- 1 - (1 - ans$r.squared) * ((n - df.int) / rdf)
         ans$fstatistic <- c(value = (mss / (p - df.int)) / resvar,
-            numdf = p - df.int, dendf = rdf)
+                            numdf = p - df.int, dendf = rdf)
     } else {
         ans$r.squared <- ans$adj.r.squared <- 0
     }
