@@ -1,6 +1,6 @@
 /* weighted quantile and selection of k-th largest element
 
-   Copyright (C) 2020 Tobias Schoch (e-mail: tobias.schoch@gmail.com)
+   Copyright (C) 2020-2022 Tobias Schoch (e-mail: tobias.schoch@gmail.com)
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,9 +30,8 @@
 
 static inline void swap2(double*, double*, int, int)
     __attribute__((always_inline));
-static inline double med3(double*, int, int, int)
+static inline int med3(double*, int, int, int)
     __attribute__((always_inline));
-static inline int min(int, int) __attribute__((always_inline));
 static inline int choose_pivot(double*, int, int)
     __attribute__((always_inline));
 static inline int is_equal(double, double) __attribute__((always_inline));
@@ -116,12 +115,17 @@ void wquant0(double *array, double *weights, double sum_w, int lo, int hi,
     debug_print_data(array, weights, lo, hi, "init");
     #endif
 
-    if (hi <= lo)               // case: n = 1
+    if (hi <= lo) {              // case: n = 1
+        *result = array[lo];
         return;
+    }
 
     if (hi - lo == 1) {         // case: n = 2
         double one_minus = 1.0 - prob;
 
+        if (array[lo] > array[hi])
+            swap2(array, weights, lo, hi);
+
         if (is_equal(one_minus * weights[lo], prob * weights[hi]))
             *result = (array[lo] + array[hi]) / 2.0;
         else if (one_minus * weights[lo] > prob * weights[hi])
@@ -296,14 +300,6 @@ static inline void swap2(double *array, double *weights, int i, int j)
     tmp = weights[i]; weights[i] = weights[j]; weights[j] = tmp;
 }
 
-/******************************************************************************\
-|* minimum of two integer values                                              *|
-\******************************************************************************/
-static inline int min(int a, int b)
-{
-    return a < b ? a : b;
-}
-
 /******************************************************************************\
 |* check whether two doubles are equal using Knuth's notion of essential      *|
 |* equality                                                                   *|
@@ -317,7 +313,7 @@ static inline int is_equal(double a, double b)
 /******************************************************************************\
 |* median-of-three (but without swaps)                                        *|
 \******************************************************************************/
-static inline double med3(double *array, int i, int j, int k)
+static inline int med3(double *array, int i, int j, int k)
 {
     return array[i] < array[j] ?
         (array[j] < array[k] ? j : array[i] < array[k] ? k : i)
